documentationtools.GraphvizEdge
===============================

.. abjad-lineage:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.GraphvizEdge

.. autoclass:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.GraphvizEdge
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.GraphvizEdge.attributes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.GraphvizEdge.head
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.GraphvizEdge.storage_format
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.GraphvizEdge.tail
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.GraphvizEdge.is_directed
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.GraphvizEdge.__call__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.GraphvizEdge.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.GraphvizEdge.__ge__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.GraphvizEdge.__gt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.GraphvizEdge.__le__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.GraphvizEdge.__lt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.GraphvizEdge.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.GraphvizEdge.__repr__
   :noindex:
